@@ -8,7 +8,7 @@ use Mojo::Util 'steady_time';
 use Sys::Hostname 'hostname';
 use Time::HiRes 'usleep';
 
-our $VERSION = '4.003';
+our $VERSION = '4.004';
 
 has dequeue_interval => 0.5;
 has 'sqlite';
@@ -135,7 +135,8 @@ sub list_jobs {
        strftime('%s',delayed) as delayed,
        strftime('%s',finished) as finished, notes, parents, priority, queue,
        result, strftime('%s',retried) as retried, retries,
-       strftime('%s',started) as started, state, task, worker
+       strftime('%s',started) as started, state, task,
+       strftime('%s','now') as time, worker
        from minion_jobs as j
        $where_str order by id desc limit ? offset ?},
     @where_params, $limit, $offset
@@ -791,6 +792,12 @@ Current job state, usually C<active>, C<failed>, C<finished> or C<inactive>.
 
 Task name.
 
+=item time
+
+  time => 78411177
+
+Current time.
+
 =item worker
 
   worker => '154'
